@@ -17,37 +17,16 @@
 
 
 /////////////////////////////////////////////////////////////////
-// set predefined variables as if magic_quotes_gpc was off,
-// whether the server's got it or not:
-UnifyMagicQuotes(false);
-/////////////////////////////////////////////////////////////////
-
-
-/////////////////////////////////////////////////////////////////
-// showfile is used to display embedded images from table_var_dump()
-// md5 of requested file is required to prevent abuse where any
-// random file on the server could be viewed
-if (@$_REQUEST['showfile']) {
-	if (is_readable($_REQUEST['showfile'])) {
-		if (md5_file($_REQUEST['showfile']) == @$_REQUEST['md5']) {
-			readfile($_REQUEST['showfile']);
-			exit;
-		}
-	}
-	die('Cannot display "'.$_REQUEST['showfile'].'"');
+// die if magic_quotes_runtime or magic_quotes_gpc are set
+if (function_exists('get_magic_quotes_runtime') && get_magic_quotes_runtime()) {
+	die('magic_quotes_runtime is enabled, getID3 will not run.');
+}
+if (function_exists('get_magic_quotes_gpc') && get_magic_quotes_gpc()) {
+	die('magic_quotes_gpc is enabled, getID3 will not run.');
 }
 /////////////////////////////////////////////////////////////////
 
-
-if (!function_exists('getmicrotime')) {
-	function getmicrotime() {
-		list($usec, $sec) = explode(' ', microtime());
-		return ((float) $usec + (float) $sec);
-	}
-}
-
-///////////////////////////////////////////////////////////////////////////////
-
+$PageEncoding = 'UTF-8';
 
 $writescriptfilename = 'demo.write.php';
 
@@ -58,7 +37,7 @@ define('GETID3_HELPERAPPSDIR', 'C:/helperapps/');
 
 // Initialize getID3 engine
 $getID3 = new getID3;
-$getID3->setOption(array('encoding' => 'UTF-8'));
+$getID3->setOption(array('encoding' => $PageEncoding));
 
 $getID3checkColor_Head           = 'CCCCDD';
 $getID3checkColor_DirectoryLight = 'FFCCCC';
@@ -73,7 +52,6 @@ $getID3checkColor_UnknownDark    = 'BBBBDD';
 
 
 header('Content-Type: text/html; charset=UTF-8');
-ob_start();
 echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">';
 echo '<html><head>';
 echo '<title>getID3() - /demo/demo.browse.php (sample script)</title>';
@@ -103,23 +81,23 @@ if (isset($_REQUEST['filename'])) {
 	if (!file_exists($_REQUEST['filename']) || !is_file($_REQUEST['filename'])) {
 		die(getid3_lib::iconv_fallback('ISO-8859-1', 'UTF-8', $_REQUEST['filename'].' does not exist'));
 	}
-	$starttime = getmicrotime();
+	$starttime = microtime(true);
 
 	//$getID3->setOption(array(
 	//	'option_md5_data'  => $AutoGetHashes,
 	//	'option_sha1_data' => $AutoGetHashes,
 	//));
 	$ThisFileInfo = $getID3->analyze($_REQUEST['filename']);
-	$AutoGetHashes = (bool) ((@$ThisFileInfo['filesize'] > 0) && ($ThisFileInfo['filesize'] < (50 * 1048576))); // auto-get md5_data, md5_file, sha1_data, sha1_file if filesize < 50MB, and NOT zero (which may indicate a file>2GB)
+	$AutoGetHashes = (bool) (isset($ThisFileInfo['filesize']) && ($ThisFileInfo['filesize'] > 0) && ($ThisFileInfo['filesize'] < (50 * 1048576))); // auto-get md5_data, md5_file, sha1_data, sha1_file if filesize < 50MB, and NOT zero (which may indicate a file>2GB)
 	if ($AutoGetHashes) {
-		$ThisFileInfo['md5_file']  = getid3_lib::md5_file($_REQUEST['filename']);
-		$ThisFileInfo['sha1_file'] = getid3_lib::sha1_file($_REQUEST['filename']);
+		$ThisFileInfo['md5_file']  = md5_file($_REQUEST['filename']);
+		$ThisFileInfo['sha1_file'] = sha1_file($_REQUEST['filename']);
 	}
 
 
 	getid3_lib::CopyTagsToComments($ThisFileInfo);
 
-	$listdirectory = dirname(getid3_lib::SafeStripSlashes($_REQUEST['filename']));
+	$listdirectory = dirname($_REQUEST['filename']);
 	$listdirectory = realpath($listdirectory); // get rid of /../../ references
 
 	if (GETID3_OS_ISWINDOWS) {
@@ -131,16 +109,16 @@ if (isset($_REQUEST['filename'])) {
 	if (strstr($_REQUEST['filename'], 'http://') || strstr($_REQUEST['filename'], 'ftp://')) {
 		echo '<i>Cannot browse remote filesystems</i><br>';
 	} else {
-		echo 'Browse: <a href="'.$_SERVER['PHP_SELF'].'?listdirectory='.urlencode($listdirectory).'">'.getid3_lib::iconv_fallback('ISO-8859-1', 'UTF-8', $listdirectory).'</a><br>';
+		echo 'Browse: <a href="'.htmlentities($_SERVER['PHP_SELF'].'?listdirectory='.urlencode($listdirectory), ENT_QUOTES).'">'.getid3_lib::iconv_fallback('ISO-8859-1', 'UTF-8', $listdirectory).'</a><br>';
 	}
 
-	echo table_var_dump($ThisFileInfo);
-	$endtime = getmicrotime();
+	echo table_var_dump($ThisFileInfo, false, $PageEncoding);
+	$endtime = microtime(true);
 	echo 'File parsed in '.number_format($endtime - $starttime, 3).' seconds.<br>';
 
 } else {
 
-	$listdirectory = (isset($_REQUEST['listdirectory']) ? getid3_lib::SafeStripSlashes($_REQUEST['listdirectory']) : '.');
+	$listdirectory = (isset($_REQUEST['listdirectory']) ? $_REQUEST['listdirectory'] : '.');
 	$listdirectory = realpath($listdirectory); // get rid of /../../ references
 	$currentfulldir = $listdirectory.'/';
 
@@ -150,12 +128,14 @@ if (isset($_REQUEST['filename'])) {
 		$currentfulldir = str_replace('\\', '/', $listdirectory.'/');
 	}
 
-	if ($handle = @opendir($listdirectory)) {
+	ob_start();
+	if ($handle = opendir($listdirectory)) {
 
+		ob_end_clean();
 		echo str_repeat(' ', 300); // IE buffers the first 300 or so chars, making this progressive display useless - fill the buffer with spaces
 		echo 'Processing';
 
-		$starttime = getmicrotime();
+		$starttime = microtime(true);
 
 		$TotalScannedUnknownFiles  = 0;
 		$TotalScannedKnownFiles    = 0;
@@ -188,7 +168,6 @@ if (isset($_REQUEST['filename'])) {
 					continue 2;
 					break;
 			}
-
 			// symbolic-link-resolution enhancements by davidbullock״ech-center*com
 			$TargetObject     = realpath($currentfilename);  // Find actual file path, resolve if it's a symbolic link
 			$TargetObjectType = filetype($TargetObject);     // Check file type without examining extension
@@ -204,17 +183,16 @@ if (isset($_REQUEST['filename'])) {
 
 				getid3_lib::CopyTagsToComments($fileinformation);
 
-				$TotalScannedFilesize += @$fileinformation['filesize'];
+				$TotalScannedFilesize += (isset($fileinformation['filesize']) ? $fileinformation['filesize'] : 0);
 
 				if (isset($_REQUEST['ShowMD5'])) {
-					$fileinformation['md5_file'] = md5($currentfilename);
-					$fileinformation['md5_file']  = getid3_lib::md5_file($currentfilename);
+					$fileinformation['md5_file'] = md5_file($currentfilename);
 				}
 
 				if (!empty($fileinformation['fileformat'])) {
 					$DirectoryContents[$currentfulldir]['known'][$file] = $fileinformation;
-					$TotalScannedPlaytime += @$fileinformation['playtime_seconds'];
-					$TotalScannedBitrate  += @$fileinformation['bitrate'];
+					$TotalScannedPlaytime += (isset($fileinformation['playtime_seconds']) ? $fileinformation['playtime_seconds'] : 0);
+					$TotalScannedBitrate  += (isset($fileinformation['bitrate'])          ? $fileinformation['bitrate']          : 0);
 					$TotalScannedKnownFiles++;
 				} else {
 					$DirectoryContents[$currentfulldir]['other'][$file] = $fileinformation;
@@ -229,7 +207,7 @@ if (isset($_REQUEST['filename'])) {
 				}
 			}
 		}
-		$endtime = getmicrotime();
+		$endtime = microtime(true);
 		closedir($handle);
 		echo 'done<br>';
 		echo 'Directory scanned in '.number_format($endtime - $starttime, 2).' seconds.<br>';
@@ -247,7 +225,7 @@ if (isset($_REQUEST['filename'])) {
 					echo '<tr bgcolor="#'.(($rowcounter++ % 2) ? $getID3checkColor_DirectoryLight : $getID3checkColor_DirectoryDark).'">';
 					if ($filename == '..') {
 						echo '<td colspan="'.$columnsintable.'">';
-						echo '<form action="'.$_SERVER['PHP_SELF'].'" method="get">';
+						echo '<form action="'.htmlentities($_SERVER['PHP_SELF'], ENT_QUOTES).'" method="get">';
 						echo 'Parent directory: ';
 						echo '<input type="text" name="listdirectory" size="50" style="background-color: '.$getID3checkColor_DirectoryDark.';" value="';
 						if (GETID3_OS_ISWINDOWS) {
@@ -258,7 +236,7 @@ if (isset($_REQUEST['filename'])) {
 						echo '"> <input type="submit" value="Go">';
 						echo '</form></td>';
 					} else {
-						echo '<td colspan="'.$columnsintable.'"><a href="'.$_SERVER['PHP_SELF'].'?listdirectory='.urlencode($dirname.$filename).'"><b>'.FixTextFields($filename).'</b></a></td>';
+						echo '<td colspan="'.$columnsintable.'"><a href="'.htmlentities($_SERVER['PHP_SELF'].'?listdirectory='.urlencode($dirname.$filename), ENT_QUOTES).'"><b>'.htmlentities($filename).'</b></a></td>';
 					}
 					echo '</tr>';
 				}
@@ -273,11 +251,11 @@ if (isset($_REQUEST['filename'])) {
 			echo '<th>Artist</th>';
 			echo '<th>Title</th>';
 			if (isset($_REQUEST['ShowMD5'])) {
-				echo '<th>MD5&nbsp;File (File) (<a href="'.$_SERVER['PHP_SELF'].'?listdirectory='.rawurlencode(isset($_REQUEST['listdirectory']) ? $_REQUEST['listdirectory'] : '.').'">disable</a>)</th>';
-				echo '<th>MD5&nbsp;Data (File) (<a href="'.$_SERVER['PHP_SELF'].'?listdirectory='.rawurlencode(isset($_REQUEST['listdirectory']) ? $_REQUEST['listdirectory'] : '.').'">disable</a>)</th>';
-				echo '<th>MD5&nbsp;Data (Source) (<a href="'.$_SERVER['PHP_SELF'].'?listdirectory='.rawurlencode(isset($_REQUEST['listdirectory']) ? $_REQUEST['listdirectory'] : '.').'">disable</a>)</th>';
+				echo '<th>MD5&nbsp;File (File) (<a href="'.htmlentities($_SERVER['PHP_SELF'].'?listdirectory='.rawurlencode(isset($_REQUEST['listdirectory']) ? $_REQUEST['listdirectory'] : '.'), ENT_QUOTES).'">disable</a>)</th>';
+				echo '<th>MD5&nbsp;Data (File) (<a href="'.htmlentities($_SERVER['PHP_SELF'].'?listdirectory='.rawurlencode(isset($_REQUEST['listdirectory']) ? $_REQUEST['listdirectory'] : '.'), ENT_QUOTES).'">disable</a>)</th>';
+				echo '<th>MD5&nbsp;Data (Source) (<a href="'.htmlentities($_SERVER['PHP_SELF'].'?listdirectory='.rawurlencode(isset($_REQUEST['listdirectory']) ? $_REQUEST['listdirectory'] : '.'), ENT_QUOTES).'">disable</a>)</th>';
 			} else {
-				echo '<th colspan="3">MD5&nbsp;Data (<a href="'.$_SERVER['PHP_SELF'].'?listdirectory='.rawurlencode(isset($_REQUEST['listdirectory']) ? $_REQUEST['listdirectory'] : '.').'&amp;ShowMD5=1">enable</a>)</th>';
+				echo '<th colspan="3">MD5&nbsp;Data (<a href="'.htmlentities($_SERVER['PHP_SELF'].'?listdirectory='.rawurlencode(isset($_REQUEST['listdirectory']) ? $_REQUEST['listdirectory'] : '.').'&ShowMD5=1', ENT_QUOTES).'">enable</a>)</th>';
 			}
 			echo '<th>Tags</th>';
 			echo '<th>Errors &amp; Warnings</th>';
@@ -289,13 +267,13 @@ if (isset($_REQUEST['filename'])) {
 				uksort($DirectoryContents[$dirname]['known'], 'MoreNaturalSort');
 				foreach ($DirectoryContents[$dirname]['known'] as $filename => $fileinfo) {
 					echo '<tr bgcolor="#'.(($rowcounter++ % 2) ? $getID3checkColor_FileDark : $getID3checkColor_FileLight).'">';
-					echo '<td><a href="'.$_SERVER['PHP_SELF'].'?filename='.urlencode($dirname.$filename).'" title="View detailed analysis">'.FixTextFields(getid3_lib::SafeStripSlashes($filename)).'</a></td>';
+					echo '<td><a href="'.htmlentities($_SERVER['PHP_SELF'].'?filename='.urlencode($dirname.$filename), ENT_QUOTES).'" title="View detailed analysis">'.htmlentities($filename).'</a></td>';
 					echo '<td align="right">&nbsp;'.number_format($fileinfo['filesize']).'</td>';
 					echo '<td align="right">&nbsp;'.NiceDisplayFiletypeFormat($fileinfo).'</td>';
 					echo '<td align="right">&nbsp;'.(isset($fileinfo['playtime_string']) ? $fileinfo['playtime_string'] : '-').'</td>';
-					echo '<td align="right">&nbsp;'.(isset($fileinfo['bitrate']) ? BitrateText($fileinfo['bitrate'] / 1000, 0, ((@$fileinfo['audio']['bitrate_mode'] == 'vbr') ? true : false)) : '-').'</td>';
-					echo '<td align="left">&nbsp;'.(isset($fileinfo['comments_html']['artist']) ? implode('<br>', $fileinfo['comments_html']['artist']) : '').'</td>';
-					echo '<td align="left">&nbsp;'.(isset($fileinfo['comments_html']['title']) ? implode('<br>', $fileinfo['comments_html']['title']) : '').'</td>';
+					echo '<td align="right">&nbsp;'.(isset($fileinfo['bitrate']) ? BitrateText($fileinfo['bitrate'] / 1000, 0, ((isset($fileinfo['audio']['bitrate_mode']) && ($fileinfo['audio']['bitrate_mode'] == 'vbr')) ? true : false)) : '-').'</td>';
+					echo '<td align="left">&nbsp;'.(isset($fileinfo['comments_html']['artist']) ? implode('<br>', $fileinfo['comments_html']['artist']) : ((isset($fileinfo['video']['resolution_x']) && isset($fileinfo['video']['resolution_y'])) ? $fileinfo['video']['resolution_x'].'x'.$fileinfo['video']['resolution_y'] : '')).'</td>';
+					echo '<td align="left">&nbsp;'.(isset($fileinfo['comments_html']['title'])  ? implode('<br>', $fileinfo['comments_html']['title'])  :  (isset($fileinfo['video']['frame_rate'])                                                 ? number_format($fileinfo['video']['frame_rate'], 3).'fps'                  : '')).'</td>';
 					if (isset($_REQUEST['ShowMD5'])) {
 						echo '<td align="left"><tt>'.(isset($fileinfo['md5_file'])        ? $fileinfo['md5_file']        : '&nbsp;').'</tt></td>';
 						echo '<td align="left"><tt>'.(isset($fileinfo['md5_data'])        ? $fileinfo['md5_data']        : '&nbsp;').'</tt></td>';
@@ -303,41 +281,40 @@ if (isset($_REQUEST['filename'])) {
 					} else {
 						echo '<td align="center" colspan="3">-</td>';
 					}
-					echo '<td align="left">&nbsp;'.@implode(', ', array_keys($fileinfo['tags'])).'</td>';
+					echo '<td align="left">&nbsp;'.(!empty($fileinfo['tags']) ? implode(', ', array_keys($fileinfo['tags'])) : '').'</td>';
 
 					echo '<td align="left">&nbsp;';
 					if (!empty($fileinfo['warning'])) {
 						$FilesWithWarnings++;
-						echo '<a href="#" onClick="alert(\''.FixTextFields(implode('\\n', $fileinfo['warning'])).'\'); return false;" title="'.FixTextFields(implode("\n", $fileinfo['warning'])).'">warning</a><br>';
+						echo '<a href="#" onClick="alert(\''.htmlentities(implode('\\n', $fileinfo['warning']), ENT_QUOTES).'\'); return false;" title="'.htmlentities(implode("\n", $fileinfo['warning']), ENT_QUOTES).'">warning</a><br>';
 					}
 					if (!empty($fileinfo['error'])) {
 						$FilesWithErrors++;
-						echo '<a href="#" onClick="alert(\''.FixTextFields(implode('\\n', $fileinfo['error'])).'\'); return false;" title="'.FixTextFields(implode("\n", $fileinfo['error'])).'">error</a><br>';
+						echo '<a href="#" onClick="alert(\''.htmlentities(implode('\\n', $fileinfo['error']), ENT_QUOTES).'\'); return false;" title="'.htmlentities(implode("\n", $fileinfo['error']), ENT_QUOTES).'">error</a><br>';
 					}
 					echo '</td>';
 
 					echo '<td align="left">&nbsp;';
-					switch (@$fileinfo['fileformat']) {
+					$fileinfo['fileformat'] = (isset($fileinfo['fileformat']) ? $fileinfo['fileformat'] : '');
+					switch ($fileinfo['fileformat']) {
 						case 'mp3':
 						case 'mp2':
 						case 'mp1':
 						case 'flac':
 						case 'mpc':
 						case 'real':
-							echo '<a href="'.$writescriptfilename.'?Filename='.urlencode($dirname.$filename).'" title="Edit tags">edit&nbsp;tags</a>';
+							echo '<a href="'.htmlentities($writescriptfilename.'?Filename='.urlencode($dirname.$filename), ENT_QUOTES).'" title="Edit tags">edit&nbsp;tags</a>';
 							break;
 						case 'ogg':
-							switch (@$fileinfo['audio']['dataformat']) {
-								case 'vorbis':
-									echo '<a href="'.$writescriptfilename.'?Filename='.urlencode($dirname.$filename).'" title="Edit tags">edit&nbsp;tags</a>';
-									break;
+							if (isset($fileinfo['audio']['dataformat']) && ($fileinfo['audio']['dataformat'] == 'vorbis')) {
+								echo '<a href="'.htmlentities($writescriptfilename.'?Filename='.urlencode($dirname.$filename), ENT_QUOTES).'" title="Edit tags">edit&nbsp;tags</a>';
 							}
 							break;
 						default:
 							break;
 					}
 					echo '</td>';
-					echo '<td align="left">&nbsp;<a href="'.$_SERVER['PHP_SELF'].'?listdirectory='.urlencode($listdirectory).'&amp;deletefile='.urlencode($dirname.$filename).'" onClick="return confirm(\'Are you sure you want to delete '.addslashes(htmlentities($dirname.$filename)).'? \n(this action cannot be un-done)\');" title="Permanently delete '."\n".FixTextFields($filename)."\n".' from'."\n".' '.FixTextFields($dirname).'">delete</a></td>';
+					echo '<td align="left">&nbsp;<a href="'.htmlentities($_SERVER['PHP_SELF'].'?listdirectory='.urlencode($listdirectory).'&deletefile='.urlencode($dirname.$filename), ENT_QUOTES).'" onClick="return confirm(\'Are you sure you want to delete '.addslashes(htmlentities($dirname.$filename)).'? \n(this action cannot be un-done)\');" title="'.htmlentities('Permanently delete '."\n".$filename."\n".' from'."\n".' '.$dirname, ENT_QUOTES).'">delete</a></td>';
 					echo '</tr>';
 				}
 			}
@@ -346,7 +323,7 @@ if (isset($_REQUEST['filename'])) {
 				uksort($DirectoryContents[$dirname]['other'], 'MoreNaturalSort');
 				foreach ($DirectoryContents[$dirname]['other'] as $filename => $fileinfo) {
 					echo '<tr bgcolor="#'.(($rowcounter++ % 2) ? $getID3checkColor_UnknownDark : $getID3checkColor_UnknownLight).'">';
-					echo '<td><a href="'.$_SERVER['PHP_SELF'].'?filename='.urlencode($dirname.$filename).'"><i>'.$filename.'</i></a></td>';
+					echo '<td><a href="'.htmlentities($_SERVER['PHP_SELF'].'?filename='.urlencode($dirname.$filename), ENT_QUOTES).'"><i>'.htmlentities($filename).'</i></a></td>';
 					echo '<td align="right">&nbsp;'.(isset($fileinfo['filesize']) ? number_format($fileinfo['filesize']) : '-').'</td>';
 					echo '<td align="right">&nbsp;'.NiceDisplayFiletypeFormat($fileinfo).'</td>';
 					echo '<td align="right">&nbsp;'.(isset($fileinfo['playtime_string']) ? $fileinfo['playtime_string'] : '-').'</td>';
@@ -360,18 +337,18 @@ if (isset($_REQUEST['filename'])) {
 					echo '<td align="left">&nbsp;';
 					if (!empty($fileinfo['warning'])) {
 						$FilesWithWarnings++;
-						echo '<a href="#" onClick="alert(\''.FixTextFields(implode('\\n', $fileinfo['warning'])).'\'); return false;" title="'.FixTextFields(implode("\n", $fileinfo['warning'])).'">warning</a><br>';
+						echo '<a href="#" onClick="alert(\''.htmlentities(implode('\\n', $fileinfo['warning']), ENT_QUOTES).'\'); return false;" title="'.htmlentities(implode("\n", $fileinfo['warning']), ENT_QUOTES).'">warning</a><br>';
 					}
 					if (!empty($fileinfo['error'])) {
 						if ($fileinfo['error'][0] != 'unable to determine file format') {
 							$FilesWithErrors++;
-							echo '<a href="#" onClick="alert(\''.FixTextFields(implode('\\n', $fileinfo['error'])).'\'); return false;" title="'.FixTextFields(implode("\n", $fileinfo['error'])).'">error</a><br>';
+							echo '<a href="#" onClick="alert(\''.htmlentities(implode('\\n', $fileinfo['error']), ENT_QUOTES).'\'); return false;" title="'.htmlentities(implode("\n", $fileinfo['error']), ENT_QUOTES).'">error</a><br>';
 						}
 					}
 					echo '</td>';
 
 					echo '<td align="left">&nbsp;</td>'; // Edit
-					echo '<td align="left">&nbsp;<a href="'.$_SERVER['PHP_SELF'].'?listdirectory='.urlencode($listdirectory).'&amp;deletefile='.urlencode($dirname.$filename).'" onClick="return confirm(\'Are you sure you want to delete '.addslashes($dirname.$filename).'? \n(this action cannot be un-done)\');" title="Permanently delete '.addslashes($dirname.$filename).'">delete</a></td>';
+					echo '<td align="left">&nbsp;<a href="'.htmlentities($_SERVER['PHP_SELF'].'?listdirectory='.urlencode($listdirectory).'&deletefile='.urlencode($dirname.$filename), ENT_QUOTES).'" onClick="return confirm(\'Are you sure you want to delete '.addslashes($dirname.$filename).'? \n(this action cannot be un-done)\');" title="Permanently delete '.addslashes($dirname.$filename).'">delete</a></td>';
 					echo '</tr>';
 				}
 			}
@@ -394,13 +371,13 @@ if (isset($_REQUEST['filename'])) {
 		}
 		echo '</table>';
 	} else {
+		$errormessage = ob_get_contents();
+		ob_end_clean();
 		echo '<b>ERROR: Could not open directory: <u>'.$currentfulldir.'</u></b><br>';
 	}
 }
-echo PoweredBygetID3();
-echo 'Running on PHP v'.phpversion();
+echo PoweredBygetID3().'<br clear="all">';
 echo '</body></html>';
-ob_end_flush();
 
 
 /////////////////////////////////////////////////////////////////
@@ -450,17 +427,13 @@ function BitrateColor($bitrate, $BitrateMaxScale=768) {
 }
 
 function BitrateText($bitrate, $decimals=0, $vbr=false) {
-	return '<SPAN STYLE="color: #'.BitrateColor($bitrate).($vbr ? '; font-weight: bold;' : '').'">'.number_format($bitrate, $decimals).' kbps</SPAN>';
+	return '<span style="color: #'.BitrateColor($bitrate).($vbr ? '; font-weight: bold;' : '').'">'.number_format($bitrate, $decimals).' kbps</span>';
 }
 
-function FixTextFields($text) {
-	$text = getid3_lib::SafeStripSlashes($text);
-	$text = htmlentities($text, ENT_QUOTES);
-	return $text;
-}
-
-
 function string_var_dump($variable) {
+	if (version_compare(PHP_VERSION, '4.3.0', '>=')) {
+		return print_r($variable, true);
+	}
 	ob_start();
 	var_dump($variable);
 	$dumpedvariable = ob_get_contents();
@@ -469,7 +442,7 @@ function string_var_dump($variable) {
 }
 
 
-function table_var_dump($variable, $wrap_in_td=false) {
+function table_var_dump($variable, $wrap_in_td=false, $encoding='ISO-8859-1') {
 	$returnstring = '';
 	switch (gettype($variable)) {
 		case 'array':
@@ -483,17 +456,13 @@ function table_var_dump($variable, $wrap_in_td=false) {
 				} elseif (is_string($value)) {
 					$returnstring .= '&nbsp;('.strlen($value).')';
 				}
-				if (($key == 'data') && isset($variable['image_mime']) && isset($variable['dataoffset'])) {
+				//if (($key == 'data') && isset($variable['image_mime']) && isset($variable['dataoffset'])) {
+				if (($key == 'data') && isset($variable['image_mime'])) {
 					$imageinfo = array();
 					$imagechunkcheck = getid3_lib::GetDataImageSize($value, $imageinfo);
-					$DumpedImageSRC = (!empty($_REQUEST['filename']) ? $_REQUEST['filename'] : '.getid3').'.'.$variable['dataoffset'].'.'.getid3_lib::ImageTypesLookup($imagechunkcheck[2]);
-					if ($tempimagefile = @fopen($DumpedImageSRC, 'wb')) {
-						fwrite($tempimagefile, $value);
-						fclose($tempimagefile);
-					}
-					$returnstring .= '</td><td><img src="'.$_SERVER['PHP_SELF'].'?showfile='.urlencode($DumpedImageSRC).'&md5='.md5_file($DumpedImageSRC).'" width="'.$imagechunkcheck[0].'" height="'.$imagechunkcheck[1].'"></td></tr>';
+					$returnstring .= '</td><td><img src="data:image/gif;base64,'.base64_encode($value).'" width="'.$imagechunkcheck[0].'" height="'.$imagechunkcheck[1].'"></td></tr>';
 				} else {
-					$returnstring .= '</td>'.table_var_dump($value, true).'</tr>';
+					$returnstring .= '</td>'.table_var_dump($value, true, $encoding).'</tr>';
 				}
 			}
 			$returnstring .= '</table>';
@@ -522,11 +491,7 @@ function table_var_dump($variable, $wrap_in_td=false) {
 			$variable = str_replace("\x00", ' ', $variable);
 			$varlen = strlen($variable);
 			for ($i = 0; $i < $varlen; $i++) {
-				if (ereg('['."\x0A\x0D".' -;0-9A-Za-z]', $variable{$i})) {
-					$returnstring .= $variable{$i};
-				} else {
-					$returnstring .= '&#'.str_pad(ord($variable{$i}), 3, '0', STR_PAD_LEFT).';';
-				}
+				$returnstring .= htmlentities($variable{$i}, ENT_QUOTES, $encoding);
 			}
 			$returnstring = ($wrap_in_td ? '<td class="dump_string">' : '').nl2br($returnstring).($wrap_in_td ? '</td>' : '');
 			break;
@@ -620,60 +585,11 @@ function MoreNaturalSort($ar1, $ar2) {
 	return 0;
 }
 
-function PoweredBygetID3($string='<br><HR NOSHADE><DIV STYLE="font-size: 8pt; font-face: sans-serif;">Powered by <a href="http://getid3.sourceforge.net" TARGET="_blank"><b>getID3() v<!--GETID3VER--></b><br>http://getid3.sourceforge.net</a></DIV>') {
+function PoweredBygetID3($string='') {
+	if (!$string) {
+		$string = '<div style="border: 1px #CCCCCC solid; padding: 5px; margin: 5px 0px; float: left; background-color: #EEEEEE; font-size: 8pt; font-face: sans-serif;">Powered by <a href="http://getid3.sourceforge.net"><b>getID3() v<!--GETID3VER--></b><br>http://getid3.sourceforge.net</a><br>Running on PHP v'.phpversion().' ('.(ceil(log(PHP_INT_MAX, 2)) + 1).'-bit)</div>';
+	}
 	return str_replace('<!--GETID3VER-->', GETID3_VERSION, $string);
 }
 
-
-/////////////////////////////////////////////////////////////////
-// Unify the contents of GPC,
-// whether magic_quotes_gpc is on or off
-
-function AddStripSlashesArray($input, $addslashes=false) {
-	if (is_array($input)) {
-
-		$output = $input;
-		foreach ($input as $key => $value) {
-			$output[$key] = AddStripSlashesArray($input[$key]);
-		}
-		return $output;
-
-	} elseif ($addslashes) {
-		return addslashes($input);
-	}
-	return stripslashes($input);
-}
-
-function UnifyMagicQuotes($turnon=false) {
-	global $HTTP_GET_VARS, $HTTP_POST_VARS, $HTTP_COOKIE_VARS;
-
-	if (get_magic_quotes_gpc() && !$turnon) {
-
-		// magic_quotes_gpc is on and we want it off!
-		$_GET    = AddStripSlashesArray($_GET,    true);
-		$_POST   = AddStripSlashesArray($_POST,   true);
-		$_COOKIE = AddStripSlashesArray($_COOKIE, true);
-
-		unset($_REQUEST);
-		$_REQUEST = array_merge_recursive($_GET, $_POST, $_COOKIE);
-
-	} elseif (!get_magic_quotes_gpc() && $turnon) {
-
-		// magic_quotes_gpc is off and we want it on (why??)
-		$_GET    = AddStripSlashesArray($_GET,    true);
-		$_POST   = AddStripSlashesArray($_POST,   true);
-		$_COOKIE = AddStripSlashesArray($_COOKIE, true);
-
-		unset($_REQUEST);
-		$_REQUEST = array_merge_recursive($_GET, $_POST, $_COOKIE);
-
-	}
-	$HTTP_GET_VARS    = $_GET;
-	$HTTP_POST_VARS   = $_POST;
-	$HTTP_COOKIE_VARS = $_COOKIE;
-
-	return true;
-}
-/////////////////////////////////////////////////////////////////
-
 ?>
\ No newline at end of file
